@@ -37,8 +37,9 @@ def generate_bootstrap_count_curves(
     fig, ax = plt.subplots(figsize=[20, 9])
     ins = ax.inset_axes([0.05, 0.05, 0.45, 0.4])
     ins.set_xlim([0.8, 1.0])
-    ins.set_xticks([.85, .9, .95, 1.], fontsize=30)
-    ins.set_ylim(bottom=0.2)
+    ins.set_xticks([.85, .9, .95], [.85, .9, .95], fontsize=30)
+    ins.yaxis.tick_right()
+    ins.xaxis.tick_top()
 
     collected_rocs = {'precision': {}, 'recall': {}}
 
