@@ -77,7 +77,12 @@ def generate_count_curve(
         fig, ax = plt.subplots(figsize=[20, 9])
         ins = ax.inset_axes([0.05, 0.05, 0.45, 0.4])
         ins.set_xlim([0.65, 1.0])
-        ins.set_xticks([.7, .75, .8, .85, .9, .95], fontsize=30)
+        ins.set_xticks(
+            [.7, .75, .8, .85, .9, .95],
+            [.7, .75, .8, .85, .9, .95], fontsize=30,
+        )
+        ins.yaxis.tick_right()
+        ins.xaxis.tick_top()
 
     for category_id in precision:
         prec = precision[category_id]
