@@ -38,7 +38,11 @@ def generate_bootstrap_froc_curves(
     fig, ax = plt.subplots(figsize=[27, 10])
     ins = ax.inset_axes([0.55, 0.05, 0.45, 0.4])
     ins.set_xlim([0.1, 5.0])
-    ins.set_xticks([0.1, 1.0, 2.0, 3.0, 4.0])
+    ins.set_xticks(
+        [0.1, 1.0, 2.0, 3.0, 4.0], [
+            0.1, 1.0, 2.0, 3.0, 4.0,
+        ], fontsize=30,
+    )
 
     collected_frocs = {'lls': {}, 'nlls': {}}
 
